@@ -121,13 +121,7 @@ def endlock(series):
          plt.subplot(122)
          plt.title('Endlocked (nans at start)')
          plt.plot(dm.y2.plottable)
-         plt.savefig('content/pages/img/series/endlock.png')
-        --%
-
-        %--
-        figure:
-         source: endlock.png
-         id: FigEndLock
+         plt.show()
         --%
 
     arguments:
@@ -202,13 +196,7 @@ def lock(series, lock):
          plt.title('Locked to peak')
          plt.plot(dm.y2.plottable)
          plt.axvline(zero_point, color='black', linestyle=':')
-         plt.savefig('content/pages/img/series/lock.png')
-        --%
-
-        %--
-        figure:
-         source: lock.png
-         id: FigLock
+         plt.show()
         --%
 
     arguments:
@@ -284,13 +272,7 @@ def normalize_time(dataseries, timeseries):
          plt.plot(dm.interpolated.plottable, ':')
          plt.xlabel('Time')
          plt.ylabel('Data')
-         plt.savefig('content/pages/img/series/normalize_time.png')
-        --%
-
-        %--
-        figure:
-         source: normalize_time.png
-         id: FigNormalizeTime
+         plt.show()
         --%
 
     arguments:
@@ -423,7 +405,7 @@ def window(series, start=0, end=None):
          from datamatrix import DataMatrix, SeriesColumn, series as srs
 
          LENGTH = 5 # Number of rows
-         DEPTH = 10 # Depth (or length) of SeriesColumnsplt.show()
+         DEPTH = 10 # Depth (or length) of SeriesColumns
 
          sinewave = np.sin(np.linspace(0, 2*np.pi, DEPTH))
 
@@ -443,13 +425,7 @@ def window(series, start=0, end=None):
          plt.subplot(122)
          plt.title('Window (middle half)')
          plt.plot(dm.y2.plottable)
-         plt.savefig('content/pages/img/series/window.png')
-        --%
-
-        %--
-        figure:
-         source: window.png
-         id: FigWindow
+         plt.show()
         --%
 
     arguments:
@@ -520,13 +496,7 @@ def baseline(
          plt.subplot(122)
          plt.title('Baseline corrected')
          plt.plot(dm.y2.plottable)
-         plt.savefig('content/pages/img/series/baseline.png')
-        --%
-
-        %--
-        figure:
-         source: baseline.png
-         id: FigBaseline
+         plt.show()
         --%
 
     arguments:
@@ -574,19 +544,18 @@ def baseline(
     raise Exception('Baseline method should be divisive or subtractive')
 
 
-def blinkreconstruct(
-    series,
-    vt=5,
-    maxdur=500,
-    margin=10,
-    smooth_winlen=21,
-    std_thr=3
-):
-
+def blinkreconstruct(series, vt=5, vt_start=10, vt_end=5, maxdur=500,
+                     margin=10, smooth_winlen=21, std_thr=3, gap_margin=20,
+                     gap_vt=10, mode='original'):
     """
     desc: |
         Reconstructs pupil size during blinks. This algorithm has been designed
         and tested largely with the EyeLink 1000 eye tracker.
+        
+        *Version note:* As of 0.13.0, an advanced algorithm has been
+        introduced, wich can be specified through the `mode` keyword. The
+        advanced algorithm is recommended for new analyses, and will be made
+        the default in future releases.
 
         __Source:__
 
@@ -600,32 +569,63 @@ def blinkreconstruct(
 
     keywords:
         vt:
-            desc:   A pupil velocity threshold. Lower tresholds more easily
-                    trigger blinks.
+            desc:   A pupil-velocity threshold for blink detection. Lower
+                    tresholds more easily trigger blinks. This argument only
+                    applies to 'original' mode.
+            type:   [int, float]
+        vt_start:
+            desc:   A pupil-velocity threshold for detecting the onset of a
+                    blink. Lower tresholds more easily trigger blinks. This
+                    argument only applies to 'advanced' mode.
+            type:   [int, float]
+        vt_end:
+            desc:   A pupil-velocity threshold for detecting the offset of a
+                    blink. Lower tresholds more easily trigger blinks. This
+                    argument only applies to 'advanced' mode.
             type:   [int, float]
         maxdur:
             desc:   The maximum duration (in samples) for a blink. Longer
                     blinks are not reconstructed.
             type:   int
         margin:
-            desc:   The margin to take around missing data.
+            desc:   The margin to take around missing data that is
+                    reconstructed.
             type:   int
+        smooth_winlen:
+            desc:   The window length for a hanning window that is used to
+                    smooth the velocity profile.
+            type:   int
+        std_thr:
+            desc:   A standard-deviation threshold for when data should be
+                    considered invalid.
+            type:   [float, int]
+        gap_margin:
+            desc:   The margin to take around missing data that is not
+                    reconstructed. Only applies to advanced mode.
+            type: int
+        gap_vt:
+            desc:   A pupil-velocity threshold for detection of invalid data.
+                    Lower tresholds mean more data marked as invalid. Only
+                    applies to advanced mode.
+            type:   [int, float]
+        mode:
+            desc:   The algorithm to be used for blink reconstruction. Should
+                    be 'original' or 'advanced'. An advanced algorith was
+                    introduced in v0.13., and should be used for new analysis.
+                    The original algorithm is still the default for backwards
+                    compatibility.
+            type:   [str]
 
     returns:
         desc: A reconstructed singal.
         type: SeriesColumn
     """
 
-    return _map(
-        series,
-        _blinkreconstruct,
-        vt=vt,
-        maxdur=maxdur,
-        margin=margin,
-        smooth_winlen=21,
-        std_thr=3
-    )
-
+    return _map(series, _blinkreconstruct, vt=vt, vt_start=vt_start,
+                vt_end=vt_end, maxdur=maxdur, margin=margin,
+                smooth_winlen=smooth_winlen, std_thr=std_thr, gap_vt=gap_vt,
+                gap_margin=gap_margin, mode=mode)
+    
 
 def smooth(series, winlen=11, wintype='hanning'):
 
@@ -671,13 +671,7 @@ def smooth(series, winlen=11, wintype='hanning'):
          plt.subplot(122)
          plt.title('Smoothed')
          plt.plot(dm.y2.plottable)
-         plt.savefig('content/pages/img/series/smooth.png')
-        --%
-
-        %--
-        figure:
-         source: smooth.png
-         id: FigSmooth
+         plt.show()
         --%
 
     arguments:
@@ -738,13 +732,7 @@ def downsample(series, by, fnc=nanmean):
          plt.subplot(122)
          plt.title('Downsampled')
          plt.plot(dm.y2.plottable, 'o-')
-         plt.savefig('content/pages/img/series/downsample.png')
-        --%
-
-        %--
-        figure:
-         source: downsample.png
-         id: FigDownsample
+         plt.show()
         --%
 
     arguments:
@@ -798,15 +786,8 @@ def threshold(series, fnc, min_length=1):
          # Mark the thresholded signal
          plt.fill_between(np.arange(DEPTH), dm.t[0], color='black', alpha=.25)
          plt.plot(dm.y.plottable)
-         plt.savefig('content/pages/img/series/threshold.png')
-
          print(dm)
-        --%
-
-        %--
-        figure:
-         source: threshold.png
-         id: FigThreshold
+         plt.show()
         --%
 
     arguments:
@@ -882,13 +863,7 @@ def interpolate(series):
          plt.clf()
          plt.plot(dm.i.plottable, ':')
          plt.plot(dm.y.plottable, 'o')
-         plt.savefig('content/pages/img/series/interpolate.png')
-        --%
-
-        %--
-        figure:
-         source: interpolate.png
-         id: FigInterpolate
+         plt.show()
         --%
 
     arguments:
@@ -951,13 +926,7 @@ def filter_bandpass(series, freq_range, order=2, sampling_freq=None):
             plt.plot(dm.f[0])
             plt.plot(dm.f[1])
             plt.plot(dm.f[2])
-            plt.savefig('content/pages/img/series/bandpass.png')
-        --%
-
-        %--
-        figure:
-         source: bandpass.png
-         id: FigBandpass
+            plt.show()
         --%
 
     arguments:
@@ -1038,13 +1007,7 @@ def filter_highpass(series, freq_min, order=2, sampling_freq=None):
             plt.plot(dm.f[0])
             plt.plot(dm.f[1])
             plt.plot(dm.f[2])
-            plt.savefig('content/pages/img/series/highpass.png')
-        --%
-
-        %--
-        figure:
-         source: highpass.png
-         id: FigHighpass
+            plt.show()
         --%
 
     arguments:
@@ -1125,13 +1088,7 @@ def filter_lowpass(series, freq_max, order=2, sampling_freq=None):
             plt.plot(dm.f[0])
             plt.plot(dm.f[1])
             plt.plot(dm.f[2])
-            plt.savefig('content/pages/img/series/lowpass.png')
-        --%
-
-        %--
-        figure:
-         source: lowpass.png
-         id: FigLowpass
+            plt.show()
         --%
 
     arguments:
@@ -1208,13 +1165,7 @@ def fft(series, truncate=True):
          plt.plot(dm.f[0])
          plt.plot(dm.f[1])
          plt.plot(dm.f[2])
-         plt.savefig('content/pages/img/series/fft.png')
-        --%
-
-        %--
-        figure:
-         source: fft.png
-         id: FigFFT
+         plt.show()
         --%
 
     arguments:
@@ -1281,13 +1232,7 @@ def z(series):
          plt.plot(dm.z[0])
          plt.plot(dm.z[1])
          plt.plot(dm.z[2])
-         plt.savefig('content/pages/img/series/z.png')
-        --%
-
-        %--
-        figure:
-         source: z.png
-         id: FigZ
+         plt.show()
         --%
 
     arguments:
@@ -1377,14 +1322,9 @@ def _map(series, fnc_, **kwdict):
     return f(np.array(series))
 
 
-def _blinkreconstruct(
-    a,
-    vt=5,
-    maxdur=500,
-    margin=10,
-    smooth_winlen=21,
-    std_thr=3
-):
+def _blinkreconstruct(a, vt=5, vt_start=10, vt_end=5, maxdur=500, margin=10,
+                      gap_margin=20, gap_vt=10, smooth_winlen=21, std_thr=3,
+                      mode='original'):
 
     """
     visible: False
@@ -1392,7 +1332,20 @@ def _blinkreconstruct(
     desc:
         Reconstructs a single array.
     """
-
+    if mode == 'advanced':
+        from datamatrix._datamatrix._blinkreconstruct import \
+            _blinkreconstruct_recursive
+        return _blinkreconstruct_recursive(a, vt_start=vt_start, vt_end=vt_end,
+                                           maxdur=maxdur, margin=margin,
+                                           gap_margin=gap_margin,
+                                           gap_vt=gap_vt,
+                                           smooth_winlen=smooth_winlen,
+                                           std_thr=std_thr)
+    if mode != 'original':
+        raise ValueError(
+            'blinkreconstruct() mode should be "orignal" or "advanced"')
+    warn('Using "original" blink-reconstruction mode. For new code, '
+         '"advanced" mode is recommended.')
     # Create a copy of the signal, a smoothed version, and calculate the
     # velocity profile.
     a = np.copy(a)
@@ -1473,7 +1426,7 @@ def _blinkreconstruct(
     for i in b:
         if i == 0:
             continue
-        a[i] = a[i-1]
+        a[i] = a[i - 1]
     return a
 
 
